# QiYu-API

[![Black Format Check](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/black-format.yml/badge.svg)](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/black-format.yml)
[![CodeQL](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/codeql-analysis.yml)
[![Poetry Publish](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/poetry_pypi.yml/badge.svg)](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/poetry_pypi.yml)
[![Pylama Lint](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/pylama-lint.yml/badge.svg)](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/pylama-lint.yml)
[![pytest](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/pytest.yml/badge.svg)](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/pytest.yml)

![PyPI - Version](https://img.shields.io/pypi/v/qiyu-api)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/qiyu-api)
![PyPI - Downloads](https://img.shields.io/pypi/dm/qiyu-api)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/qiyu-api)
![GitHub repo size](https://img.shields.io/github/repo-size/qiyutechdev/qiyu-api)
![Lines of code](https://img.shields.io/tokei/lines/github/qiyutechdev/qiyu-api)

奇遇科技 Python API 集合

## 当前已经合并

* ali_sms_api (阿里云短信)
* apns_sdk_py (Apple APNs 推送)
* dtk_api     (大淘客接口)
* mob_api     (掌淘科技接口)
* py_apple_signin (Apple Sign in 接口)
* tbk_api (淘宝客标准化的类型)
* ztk_api (折淘客接口)
